class_and_tag: Prepend Class Information and Add Attributes

View source: R/class-and-tag.r

class_and_tagR Documentation

Prepend Class Information and Add Attributes

Description

listdown decorators map list element to functions. This function is provided for convenience to prepend a class and attributes, which can then be used by custom decorators to display those element.

Usage

class_and_tag(.x, new_class, ...)

Arguments

.x

an object to add class and attribute information to.

new_class

the name of the class to be prepended to .x.

...

the attributes to attach to .x.


kaneplusplus/listdown documentation built on April 24, 2023, 8:56 p.m.