Learn R Programming

listdown (version 0.5.7)

ld_site_yaml: Create a Minimal Site YAML List

Description

Create a Minimal Site YAML List

Usage

ld_site_yaml(site_name, tab_name, rmd_name, navbar_title = site_name)

Value

A list with yaml components for creating a site with multiple tabs.

Arguments

site_name

the name of the site.

tab_name

the name of the tabs on the site.

rmd_name

the name of the R Markdown files that will generate the respective tabs.

navbar_title

the title of the navigation bar (Default is the `site_name` argument.