Create a Minimal Site YAML List
ld_site_yaml(site_name, tab_name, rmd_name, navbar_title = site_name)A list with yaml components for creating a site with multiple tabs.
the name of the site.
the name of the tabs on the site.
the name of the R Markdown files that will generate the respective tabs.
the title of the navigation bar (Default is the `site_name` argument.